@@ -1,7 +1,7 @@
-#' Analysis: graph for not significant trend
+#' Analysis: Graph for not significant trend
 #' @author Gabriel Danilo Shimizu
 #' @author Leandro Simoes Azeredo Goncalves
-#' @description Ggraph for non-significant trend. Can be used within the multicurve command
+#' @description Graph for non-significant trend. Can be used within the multicurve command
 #' @param trat Numerical vector with treatments (Declare as numeric)
 #' @param resp Numerical vector containing the response of the experiment.
 #' @param ylab Dependent variable name (Accepts the \emph{expression}() function)
@@ -11,6 +11,11 @@
 #' @param legend.position Legend position (\emph{default} is "top")
 #' @param width.bar Bar width
 #' @param legend Add the legend
+#' @param textsize Font size
+#' @param pointsize shape size
+#' @param linesize line size
+#' @param pointshape format point (\emph{default} is 21)
+#' @param font.family Font family (\emph{default} is sans)
 #' @return The function returns an exploratory graph of segments
 #' @keywords non-significant
 #' @export
@@ -38,7 +43,12 @@ N_model=function(trat,
                  xlab=expression("Temperature ("^"o"*"C)"),
                  theme=theme_classic(),
                  width.bar=NA,
-                 legend.position="top"){
+                 legend.position="top",
+                 textsize=12,
+                 pointsize=4.5,
+                 linesize=0.8,
+                 pointshape=21,
+                 font.family="sans"){
   requireNamespace("ggplot2")
   dados=data.frame(trat,resp)
   medias=c()
@@ -57,18 +67,18 @@ N_model=function(trat,
   #s="not~significant"
   s=legend
   grafico=ggplot(data1,aes(x=trat,y=resp))+
-    geom_errorbar(aes(ymin=resp-desvio, ymax=resp+desvio),width=width.bar,size=0.8)+
-    geom_point(aes(color=as.factor(rep(1,length(resp)))),na.rm=T,
-               size=4.5,fill="gray",shape=21)+
+    geom_errorbar(aes(ymin=resp-desvio, ymax=resp+desvio),width=width.bar,size=linesize)+
+    geom_point(aes(color=as.factor(rep(1,length(resp)))),na.rm=TRUE,
+               size=pointsize,fill="gray",shape=pointshape)+
     theme+
     ylab(ylab)+
     xlab(xlab)+
     scale_color_manual(values="black",label=c(parse(text=s)),name="")+
-    theme(text = element_text(size=12,color="black"),
-          axis.text = element_text(size=12,color="black"),
-          axis.title = element_text(size=12,color="black"),
+    theme(text = element_text(size=textsize,color="black",family = font.family),
+          axis.text = element_text(size=textsize,color="black",family = font.family),
+          axis.title = element_text(size=textsize,color="black",family = font.family),
           legend.position = legend.position,
-          legend.text=element_text(size=12),
+          legend.text=element_text(size=textsize,family = font.family),
           legend.direction = "vertical",
           legend.text.align = 0,
           legend.justification = 0)
